@@ -1,5 +1,5 @@
-from gdsfactory.layers import lyp_to_dataclass
-from gdsfactory.types import Layer
+import gdsfactory as gf
+from gdsfactory.types import Layer, LayerLevel, LayerStack
 from pydantic import BaseModel
 
 from sky130.config import PATH
@@ -447,7 +447,219 @@ class LayerMap(BaseModel):
 
 LAYER = LayerMap()
 
+nm = 1e-3
+poly_spacer_width = 0.03
+dnwell_depth = 1.2
+dnwell_outdiff = 0.3
+pwell_depth = 0.7
+nwell_depth = 0.8
+nwell_outdiff = 0.2
+ldd_impl_depth = 0.06
+ldd_impl_radius = 0.02
+sd_impl_depth = 0.12
+sd_impl_radius = 0.04
+sti_depth = 0.3
+sti_taper = 7
+gox_thickness = 0.004
+hvgox_thickness = 0.008
+poly_thickness = 0.18
+bpsg_thickness = 0.94
+li_thickness = 0.1
+ild2_thickness = 0.43
+m1_thickness = 0.36
+ild3_thickness = 0.27 + m1_thickness
+m2_thickness = 0.36
+ild4_thickness = 0.42 + m2_thickness
+m3_thickness = 0.845
+ild5_thickness = 0.39 + m3_thickness
+m4_thickness = 0.845
+ild6_thickness = 0.505 + m4_thickness
+m5_thickness = 1.26
+capm_thickness = 0.06
+capm_diel_thickness = 0.04
+cap2m_thickness = 0.06
+cap2m_diel_thickness = 0.04
+passv_thickness = 0.6
+pi_thickness = 6.1
+pi_recess = 2.0
+
+via1_thickness = 0.27
+via2_thickness = 0.42
+via3_thickness = 0.39
+via4_thickness = 0.505
+licon1_thickness = 0.9361
+mcon_thickness = 0.075 + 0.265
+
+
+diff = (65, 20)  # Active (diffusion) area (type opposite of well/substrate underneath)
+tap = (
+    65,
+    44,
+)  # Active (diffusion) area (type equal to the well/substrate underneath) (N+ and P+)
+nwell = (64, 20)  # N-well region
+dnwell = (64, 18)  # Deep n-well region
+pwbm = (19, 44)  # Regions (in UHVI) blocked from p-well implant (DE MOS devices only)
+pwde = (124, 20)  # Regions to receive p-well drain-extended implants
+hvtr = (18, 20)  # High-Vt RF transistor implant
+hvtp = (78, 44)  # High-Vt LVPMOS implant
+ldntm = (11, 44)  # N-tip implant on SONOS devices
+hvi = (75, 20)  # High voltage (5.0V) thick oxide gate regions
+tunm = (80, 20)  # SONOS device tunnel implant
+lvtn = (125, 44)  # Low-Vt NMOS device
+poly = (66, 20)  # Polysilicon
+hvntm = (125, 20)  # High voltage N-tip implant
+nsdm = (93, 44)  # N+ source/drain implant
+psdm = (94, 20)  # P+ source/drain implant
+rpm = (86, 20)  # 300 ohms/square polysilicon resistor implant
+urpm = (79, 20)  # 2000 ohms/square polysilicon resistor implant
+npc = (95, 20)  # Nitride poly cut (under licon1 areas)
+licon1 = (66, 44)  # Contact to local interconnect
+li1 = (67, 20)  # Local interconnect
+mcon = (67, 44)  # Contact from local interconnect to metal1
+met1 = (68, 20)  # Metal 1
+via = (68, 44)  # Contact from metal 1 to metal 2
+met2 = (69, 20)  # Metal 2
+via2 = (69, 44)  # Contact from metal 2 to metal 3
+met3 = (70, 20)  # Metal 3
+via3 = (70, 44)  # Contact from metal 3 to metal 4
+met4 = (71, 20)  # Metal 4
+via4 = (71, 44)  # Contact from metal 4 to metal 5
+met5 = (72, 20)  # Metal 5
+pad = (76, 20)  # Passivation cut (opening over pads)
+nsm = (61, 20)  # Nitride seal mask
+capm = (89, 44)  # MiM capacitor plate over metal 3
+cap2m = (97, 44)  # MiM capacitor plate over metal 4
+
+
+def get_layer_stack_generic() -> LayerStack:
+    """Returns sky LayerStack."""
+    zmin_m1 = licon1_thickness + li_thickness + mcon_thickness
+    zmin_m2 = zmin_m1 + m1_thickness + via1_thickness
+    zmin_m3 = zmin_m2 + m2_thickness + via2_thickness
+    zmin_m4 = zmin_m3 + m3_thickness + via3_thickness
+    zmin_m5 = zmin_m4 + m4_thickness + via4_thickness
+
+    thickness_nwell = sd_impl_depth  # made up number
+
+    return LayerStack(
+        layers=dict(
+            poly=LayerLevel(
+                layer=poly,
+                thickness=poly_thickness,
+                zmin=0.0,
+                material="psi",
+            ),
+            dnwell=LayerLevel(
+                layer=dnwell,
+                zmin=-dnwell_depth,
+                material="n",
+                thickness=dnwell_depth,
+            ),
+            nwell=LayerLevel(
+                layer=nwell,
+                zmin=-thickness_nwell,
+                material="n",
+                thickness=thickness_nwell,
+            ),
+            pwell=LayerLevel(
+                layer=pwbm,
+                zmin=-pwell_depth,
+                material="p",
+                thickness=pwell_depth,
+            ),
+            nsdm=LayerLevel(
+                layer=nsdm,
+                zmin=-sd_impl_depth,
+                material="n",
+                thickness=sd_impl_depth,
+            ),
+            hvtp=LayerLevel(
+                layer=hvtp,
+                zmin=-sd_impl_depth,
+                material="p",
+                thickness=sd_impl_depth,
+            ),
+            licon1=LayerLevel(
+                layer=licon1,
+                zmin=0,
+                material="metal",
+                thickness=licon1_thickness,
+            ),
+            li1=LayerLevel(
+                layer=li1,
+                zmin=licon1_thickness,
+                material="metal",
+                thickness=li_thickness,
+            ),
+            mcon=LayerLevel(
+                layer=mcon,
+                zmin=licon1_thickness + li_thickness,
+                material="metal",
+                thickness=mcon_thickness,
+            ),
+            met1=LayerLevel(
+                layer=met1,
+                zmin=zmin_m1,
+                material="metal",
+                thickness=m1_thickness,
+            ),
+            via1=LayerLevel(
+                layer=via,
+                zmin=zmin_m1 + m1_thickness,
+                material="metal",
+                thickness=via1_thickness,
+            ),
+            met2=LayerLevel(
+                layer=met2,
+                zmin=zmin_m2,
+                material="metal",
+                thickness=m2_thickness,
+            ),
+            via2=LayerLevel(
+                layer=via2,
+                zmin=zmin_m2 + m2_thickness,
+                material="metal",
+                thickness=via2_thickness,
+            ),
+            met3=LayerLevel(
+                layer=met3,
+                zmin=zmin_m3,
+                material="metal",
+                thickness=m3_thickness,
+            ),
+            via3=LayerLevel(
+                layer=via3,
+                zmin=zmin_m3 + m3_thickness,
+                material="metal",
+                thickness=via3_thickness,
+            ),
+            met4=LayerLevel(
+                layer=met4,
+                zmin=zmin_m4,
+                material="metal",
+                thickness=m4_thickness,
+            ),
+            via4=LayerLevel(
+                layer=via4,
+                zmin=zmin_m4 + m4_thickness,
+                material="metal",
+                thickness=via4_thickness,
+            ),
+            met5=LayerLevel(
+                layer=met5,
+                zmin=zmin_m5,
+                material="metal",
+                thickness=m5_thickness,
+            ),
+        )
+    )
+
+
+LAYER_STACK = get_layer_stack_generic()
+LAYER_COLORS = gf.layers.load_lyp(PATH.lyp)
+
 
 if __name__ == "__main__":
-    print(PATH.lyp)
-    print(lyp_to_dataclass(PATH.lyp))
+    # print(PATH.lyp)
+    # print(lyp_to_dataclass(PATH.lyp))
+    print(LAYER_STACK.get_klayout_3d_script())
